--[[ Triage, a Healing assignment manager addon ]]

_G.Triage = LibStub("AceAddon-3.0"):NewAddon("Triage", "AceConsole-3.0", "AceComm-3.0", "AceEvent-3.0")

Triage.L = LibStub("AceLocale-3.0"):GetLocale("Triage", "enUS", true, true);



--[[ Addon level variables ]]
Triage.debug = true
Triage.debugFrame = ChatFrame1
Triage.options = {
	type = "group",
	handler = Triage,
	args = {
		["debug"] = {
			name = "Debugging",
			desc = "Toggle Debugging",
			type = "toggle",
			get = function()
				return Triage.db.profile.debug
			end,
			set = function(_, v)
				Triage.db.profile.debug = v
				Triage.debugging = v
			end,
		},
	},
}



Triage.defaults = {
	debug = true,
}



--[[ Debugging functions ]]
function Triage:Debug(str, ...)
	if not self.debugging then return end

	if not str or str:len() == 0 then
		str = "nil"
	elseif str:find("%%") and select("#", ...) > 0 then
		str = str:format(...)
	elseif select("#", ...) > 0 then
		str = string.join(" ", str, tostringall(...))
	end

	self.debugFrame:AddMessage("|c933f9fffTriage:|r " .. str)
end



--[[ Primary Addon hooks, initialize, enable, disable ]]
function Triage:OnInitialize()
  -- Code that you want to run when the addon is first loaded goes here.
  self.db = LibStub("AceDB-3.0"):New("TriageDB", { profile = self.defaults } )

  self.debugging = self.db.profile.debug
  self:Debug("OnInitialize")

  LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("Triage", self.options)

  self:RegisterChatCommand("triage", function(input)
  	self:Debug("saw command line command")
	if not input or input:trim() == "" then
		self:Debug("opening main dialog")
		-- TODO: open main dialog
	elseif input:trim() == "config" then
		self:Debug("opening config dialog")
		LibStub("AceConfigDialog-3.0"):Open("Triage")
	else
		self:Debug("parsing commandline")
		LibStub("AceConfigCmd-3.0").HandleCommand(Triage, "triage", "Triage", input)
	end
  end)
end



function Triage:OnEnable()
    -- Called when the addon is enabled
    self:RegisterEvent("PLAYER_ENTERING_WORLD")
    self:RegisterEvent("PLAYER_REGEN_DISABLED")
    self:RegisterEvent("PLAYER_REGEN_ENABLED")
end



function Triage:OnDisable()
    -- Called when the addon is disabled
end



--[[ Event callbacks ]]
function Triage:PLAYER_ENTERING_WORLD()
	-- this is needed for zoning while in combat
	self:PLAYER_REGEN_ENABLED()
end



function Triage:PLAYER_REGEN_DISABLED()
	self:Debug("Entering combat")
	Triage.inCombat = true
end



function Triage:PLAYER_REGEN_ENABLED()
	Triage.inCombat = InCombatLockdown() == 1
	if not Triage.inCombat then
		self:Debug("Leaving combat")
	end
end